<?php
/** 
 * Zyxware Technologies Copyright © 2020
 * This Copyright is not free software: you can't redistribute it and/or modify
 */
require 'site_migration_report_support_fun.inc';
require 'site_migration_report_elements.inc';

/**
 * Implementation of hook_drush_command().
 */
function site_migration_report_drush_command() {
  $items['site_migration_report'] = array(
    'description' => 'Show a migration audit report.',
    'aliases' => array('smr'),
    'arguments' => array(
      'site_name' => '(Optional) sitename.',
      'format' => '(Optional) format.',
    ),
  );
  return $items;
}

/**
 * Drush command callback for Audit.
 */
function drush_site_migration_report($format = 'json', $site_name = 'undefined') {

  $arr_content_index = smr_index_array();

  $arr_report = array();
  smr_call_elements_function($arr_content_index, $arr_report, $format);
  smr_render_report($arr_report, $format);
}

function smr_call_elements_function($arr_content_index, &$arr_report, $format, $stage = 0) {
  foreach ($arr_content_index as $function_name => $data) {
    $arr_report[] = array(
      array('template_type' => 'heading',
      'stage' => $stage,
      'data' => $data['title'])
    );
    if (function_exists($function_name)) {
      $return_result = $function_name($arr_report);
      if ($return_result === FALSE) {
        $arr_report[] = array(
          array('template_type' => 'paragraph',
          'data' => "No detail found.\n")
        );
      }
    }
    if (!empty($data['sub_elements'])) {
      smr_call_elements_function($data['sub_elements'], $arr_report, $format, ($stage + 1));
    }
  }
}

function smr_render_report($arr_report, $format) {

  foreach ($arr_report as $arr_report_element) {
    $template_fun_name = 'smr_' . $format . '_template';
    $template_fun_name($arr_report_element);
  }
}

function smr_md_template($arr_report_element) {
  foreach ($arr_report_element as $arr_report_element_data) {
    switch ($arr_report_element_data['template_type']) {

      case 'heading':
        $stage_heading = '';
        for ($counter = 0; $counter <= $arr_report_element_data['stage']; $counter++) {
          $stage_heading .= '#';
        }
        drush_print($stage_heading . ' ' . $arr_report_element_data['data']);
      break;
      case 'list':
      break;
      case 'line_with_value':

        if(empty($arr_report_element_data['value'])) {
          $arr_report_element_data['value'] = '-';
        }
        drush_print("```");
        drush_print($arr_report_element_data['label'] . ": " . $arr_report_element_data['value'] );
        drush_print("```");
      break;
      case 'line_with_value_list':
          drush_print("```");
          foreach ($arr_report_element_data['data'] as $row_line) {
            if(empty($row_line['value'])) {
              $row_line['value'] = '-';
            }
            drush_print($row_line['label'] . ": " . $row_line['value']);
          }
          drush_print("```");
      break;
      case 'paragraph':
        drush_print($arr_report_element_data['data']);
      break;
      case 'table':
        $table = new TextTable($arr_report_element_data['row_head'], $arr_report_element_data['data']);
        drush_print($table->render());
        drush_print("```");
        drush_print("Total records: " . count($arr_report_element_data['data']));
        drush_print("```");
      break;
    }
  }
}

function smr_json_template($arr_report_element) {
  $arr_site_report = smr_get_general_site_detail();
  $json_site_audit_report = json_encode($arr_site_report);
  drush_print($json_site_audit_report);
}
